==> jquery-lazyload-1.9.3.tgz: jquery-lazyload/README.md <==
# Installation
> `npm install --save @types/jquery-lazyload`

# Summary
This package contains type definitions for JQuery Lazy Load (https://github.com/tuupola/jquery_lazyload).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-lazyload.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-lazyload/index.d.ts)
````ts
// Type definitions for JQuery Lazy Load 1.9
// Project: https://github.com/tuupola/jquery_lazyload, http://www.appelsiini.net/projects/lazyload
// Definitions by: Anderson Friaça <https://github.com/AndersonFriaca>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery" />

declare namespace JQueryLazyLoad {
    interface Options {
        threshold?: number | undefined;
        failure_limit?: number | undefined;
        event?: string | undefined;
        effect?: string | undefined;
        container?: JQuery | undefined;
        data_attribute?: string | undefined;
        skip_invisible?: boolean | undefined;
        appear?: ((elementsLeft: number, options: Options) => void) | null | undefined;
        load?: ((elementsLeft?: number, options?: Options) => void) | undefined;
        placeholder?: string | undefined;
    }
}
interface JQuery {
    lazyload(options?: JQueryLazyLoad.Options): JQuery;
    on(event: 'load', callback: ((options?: JQueryLazyLoad.Options) => void)): JQuery;
}

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 16:22:28 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Anderson Friaça](https://github.com/AndersonFriaca).

==> jquery-lazyload-1.9.4.tgz: jquery-lazyload/README.md <==
# Installation
> `npm install --save @types/jquery-lazyload`

# Summary
This package contains type definitions for JQuery Lazy Load (https://github.com/tuupola/jquery_lazyload).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-lazyload.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-lazyload/index.d.ts)
````ts
// Type definitions for JQuery Lazy Load 1.9
// Project: https://github.com/tuupola/jquery_lazyload, http://www.appelsiini.net/projects/lazyload
// Definitions by: Anderson Friaça <https://github.com/AndersonFriaca>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery" />

declare namespace JQueryLazyLoad {
    interface Options {
        threshold?: number | undefined;
        failure_limit?: number | undefined;
        event?: string | undefined;
        effect?: string | undefined;
        container?: JQuery | undefined;
        data_attribute?: string | undefined;
        skip_invisible?: boolean | undefined;
        appear?: ((elementsLeft: number, options: Options) => void) | null | undefined;
        load?: ((elementsLeft?: number, options?: Options) => void) | undefined;
        placeholder?: string | undefined;
    }
}
interface JQuery {
    lazyload(options?: JQueryLazyLoad.Options): JQuery;
    on(event: "load", callback: (options?: JQueryLazyLoad.Options) => void): JQuery;
}

````

### Additional Details
 * Last updated: Fri, 15 Sep 2023 20:36:37 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Anderson Friaça](https://github.com/AndersonFriaca).
